==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/RealizacjaDarowizna.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.generic.GenericDPSObject;

public abstract class RealizacjaDarowizna extends GenericDPSObject {
    /**
     * REALIZACJA_DAROWIZNA.OPERACJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long operacjaId;

    /**
     * REALIZACJA_DAROWIZNA.PODMIOT_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long podmiotId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return REALIZACJA_DAROWIZNA.OPERACJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getOperacjaId() {
        return operacjaId;
    }

    /**
     * REALIZACJA_DAROWIZNA.OPERACJA_ID
     *
     * @param operacjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOperacjaId(Long operacjaId) {
        this.operacjaId = operacjaId;
    }

    /**
     * @return REALIZACJA_DAROWIZNA.PODMIOT_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getPodmiotId() {
        return podmiotId;
    }

    /**
     * REALIZACJA_DAROWIZNA.PODMIOT_ID
     *
     * @param podmiotId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPodmiotId(Long podmiotId) {
        this.podmiotId = podmiotId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        RealizacjaDarowizna other = (RealizacjaDarowizna) that;
        return (this.getOperacjaId() == null ? other.getOperacjaId() == null : this.getOperacjaId().equals(other.getOperacjaId()))
            && (this.getPodmiotId() == null ? other.getPodmiotId() == null : this.getPodmiotId().equals(other.getPodmiotId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getOperacjaId() == null) ? 0 : getOperacjaId().hashCode());
        result = prime * result + ((getPodmiotId() == null) ? 0 : getPodmiotId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", operacjaId=").append(operacjaId);
        sb.append(", podmiotId=").append(podmiotId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/RealizacjaDarowizna.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class RealizacjaDarowizna extends GenericDPSObject {
    /**
     * REALIZACJA_DAROWIZNA.OPERACJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long operacjaId;

    /**
     * REALIZACJA_DAROWIZNA.PODMIOT_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long podmiotId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return REALIZACJA_DAROWIZNA.OPERACJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getOperacjaId() {
        return operacjaId;
    }

    /**
     * REALIZACJA_DAROWIZNA.OPERACJA_ID
     *
     * @param operacjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOperacjaId(Long operacjaId) {
        this.operacjaId = operacjaId;
    }

    /**
     * @return REALIZACJA_DAROWIZNA.PODMIOT_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getPodmiotId() {
        return podmiotId;
    }

    /**
     * REALIZACJA_DAROWIZNA.PODMIOT_ID
     *
     * @param podmiotId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPodmiotId(Long podmiotId) {
        this.podmiotId = podmiotId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        RealizacjaDarowizna other = (RealizacjaDarowizna) that;
        return (this.getOperacjaId() == null ? other.getOperacjaId() == null : this.getOperacjaId().equals(other.getOperacjaId()))
            && (this.getPodmiotId() == null ? other.getPodmiotId() == null : this.getPodmiotId().equals(other.getPodmiotId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getOperacjaId() == null) ? 0 : getOperacjaId().hashCode());
        result = prime * result + ((getPodmiotId() == null) ? 0 : getPodmiotId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", operacjaId=").append(operacjaId);
        sb.append(", podmiotId=").append(podmiotId);
        sb.append("]");
        return sb.toString();
    }
}
